# Shortcut Functions for Geometry Operations

## Install

```
pip install invisibleroads-macros-geometry
```

## Test

```
git clone https://github.com/invisibleroads/invisibleroads-macros-geometry
cd invisibleroads-macros-geometry
pip install -e .[test]
pytest --cov=invisibleroads_macros_geometry --cov-report term-missing:skip-covered --cov-config=tox.ini tests
```
